@@ -17,6 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
+#undef GSEAL_ENABLE
+
 #include <string.h>
 
 #include <gtk/gtk.h>
